@@ -1,6 +1,6 @@
 package Net::Stomp::MooseHelpers::ReadTrace;
 {
-  $Net::Stomp::MooseHelpers::ReadTrace::VERSION = '1.5';
+  $Net::Stomp::MooseHelpers::ReadTrace::VERSION = '1.6';
 }
 {
   $Net::Stomp::MooseHelpers::ReadTrace::DIST = 'Net-Stomp-MooseHelpers';
@@ -9,6 +9,7 @@ use Moose;
 use MooseX::Types::Path::Class;
 use Net::Stomp::Frame;
 use Path::Class;
+use Carp;
 require Net::Stomp::MooseHelpers::TraceStomp;
 use namespace::autoclean;
 
@@ -60,6 +61,13 @@ sub read_frame_from_fh {
 sub trace_subdir_for_destination {
     my ($self,$destination) = @_;
 
+    if (@_==1) {
+        return $self->trace_basedir;
+    }
+
+    confess "You must pass a defined, non-empty destination"
+        if !length($destination);
+
     return $self->trace_basedir->subdir(
         Net::Stomp::MooseHelpers::TracerRole->
               _dirname_from_destination($destination)
@@ -68,9 +76,9 @@ sub trace_subdir_for_destination {
 
 
 sub sorted_filenames {
-    my ($self,$destination) = @_;
+    my $self=shift;
 
-    my $dir = $self->trace_subdir_for_destination($destination);
+    my $dir = $self->trace_subdir_for_destination(@_);
 
     return unless -e $dir;
 
@@ -90,9 +98,9 @@ sub sorted_filenames {
 
 
 sub clear_destination {
-    my ($self,$destination) = @_;
+    my $self=shift;
 
-    my $dir = $self->trace_subdir_for_destination($destination);
+    my $dir = $self->trace_subdir_for_destination(@_);
 
     $dir->rmtree;$dir->mkpath;
 
@@ -101,16 +109,17 @@ sub clear_destination {
 
 
 sub sorted_frames {
-    my ($self,$destination) = @_;
+    my $self=shift;
 
     return map {
         $self->read_frame_from_filename($_)
-    } $self->sorted_filenames($destination);
+    } $self->sorted_filenames(@_);
 }
 
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
@@ -121,7 +130,7 @@ Net::Stomp::MooseHelpers::ReadTrace - class to read the output of L<Net::Stomp::
 
 =head1 VERSION
 
-version 1.5
+version 1.6
 
 =head1 SYNOPSIS
 
@@ -177,6 +186,10 @@ destination.
 C<< ->trace_subdir_for_destination() >> is the same as C<<
 ->trace_basedir >>.
 
+Passing an explicit C<undef> or an empty string will throw an
+exception, see L</sorted_filenames> and L</clear_destination> for the
+reason.
+
 =head2 C<sorted_filenames>
 
   my @names = $reader->sorted_filenames();
@@ -187,7 +200,14 @@ frame dump filenames found under the corresponding dump directory
 under L</trace_basedir>, sorted by filename (that is, by timestamp).
 
 If you don't specify a destination, all filenames from all
-destinations will be returned.
+destinations will be returned. Passing an explicit C<undef> or an
+empty string will throw an exception, to save you when you try doing
+things like:
+
+  my $dest = get_something_from_config;
+  my @names = $reader->sorted_filenames($dest);
+
+and end up getting way more items than you thought.
 
 =head2 C<clear_destination>
 
@@ -197,8 +217,14 @@ destinations will be returned.
 Given a destination (C</queue/something> or similar), removes all
 stored frames for it.
 
-If you don't specify a destination, all frames for all
-destinations will be removed.
+If you don't specify a destination, all frames for all destinations
+will be removed. Passing an explicit C<undef> or an empty string will
+throw an exception, to save you when you try doing things like:
+
+  my $dest = get_something_from_config;
+  $reader->clear_destination($dest);
+
+and end up deleting way more than you thought.
 
 =head2 C<sorted_frames>
 
@@ -220,4 +246,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
